@@ -33,8 +33,9 @@
 # Robin.antiX 06/08/2021 bugfix: mechanical (rotational) USB hdds did not spun down after unmounting, so it was not safe to unplug them wheras script tells user it was. Therefore it was neccessary to change default behaviour from “unsafe” to “safe” so user has to deactivate support for spinning devices actively by passing -u or -i option.
 # Robin.antiX 06/13/2021 bugfix: complete code rewrite for ver. 0.84 , geting rid of confusing variety of unconnected lists, replacing them by correlated arrays. New engine design allows to handle mountpoints containing blanks, and check for nested mounts (e.g. used on antiX live systems). New clear dialog design, so no extra confirmation dialogs needed anymore.
 # Robin.antiX 10/21/2021 new feature in ver 0.90: supports closing of luks encrypted partitions.
-# Robin.antiX 10/21/2021 unplugdrive ver. 0.91 is able to run with sudo and without as well. Some of its features may still not work without using sudo.
+# Robin.antiX 10/21/2021 unplugdrive ver. 0.91 is able to run with sudo and without as well. Some of its features may still not work without using sudo, waiting for specialy crafted pumount version.
 # nXecure - 2021-10-24 Reduced complexity, separated stages and other blocks into functions, improved performance and reuse pmount for non-sudo
+# Robin.antiX 11/18/2021 display bugfix ver. 0.93a: unmounted mointpoints listed in final message are not properly separated into partitions, showing all of them more than once.
 
 ### Please Note: text strings for debug output dont't need to get marked for translation.
 
@@ -47,7 +48,7 @@ TEXTDOMAINDIR=/usr/share/locale
 TEXTDOMAIN=unplugdrive
 
 title=$"Unplug USB device"
-version="0.93"
+version="0.93a"
 txt_version=$"Version "$version                    #text string for translation
 
 icon_taskbar="/usr/share/icons/numix-square-antix/48x48/devices/usbpendrive_unmount.png"
@@ -385,7 +386,8 @@ stage_1() {
                 mount_point_array+=("$mountpoint")
                 echo_debug "        └─ $mountpoint"
                 mountpoints_paths[$v]="${mountpoints_paths[$v]}$mountpoint|"
-                
+                mountpoints_partitions[$v]="${mountpoints_partitions[$v]}$device|"
+
                 # Check if device should be blocked
                 check_nested "$mountpoint" && \
                 DISABLED_BLOCKS="$DISABLED_BLOCKS"$'\n'"${block_name_array[$v]}" && \
@@ -619,7 +621,15 @@ stage_4() {
                     done <<<"$(findmnt --list -n -o SOURCE,TARGET | grep $device | tr -s ' ' | cut -d ' ' -f 2-)"                    
                 # If properly unmounted, then add to summary
                 else
-                    summarylist="$summarylist\n<u>$txt_dlg_device $(echo $device | rev | cut -d/ -f1 | rev)</u>\n\t$(echo "${mountpoints_paths[$v]}" | tr '\t' '|' | tr -s '|' | sed 's/|$//;s/|/\n\t/g')"
+                    summarylist="$summarylist\n<u>$txt_dlg_device $(echo $device | rev | cut -d/ -f1 | rev)</u>"
+                    w=1
+                    while read -d'|' item; do
+						if [ "$item" == "$device" ]; then
+							summarylist="$summarylist\n\t$(echo "${mountpoints_paths[$v]}" | cut -d '|' -f $w  | tr '\t' '|' | tr -s '|' | sed 's/|$//;s/|/\n\t/g')"
+						fi
+						let $((w++))
+                    done <<<"${mountpoints_partitions[$v]}"
+                    
                 fi
             done < <(echo "$RELATED_DEVICES")
             
@@ -633,7 +643,7 @@ stage_4() {
                         echo_debug hdparm -Y "$BLOCK_PATH"
                         if [ $flag_dryrun != 1 ]; then
                             hdparm -Y "$BLOCK_PATH" || \
-                            txt_rotationalerror="$txt_rotationalerror$BLOCK_NAME  "
+                            if ! echo "$txt_rotationalerror" | grep "$BLOCK_NAME"; then txt_rotationalerror="$txt_rotationalerror$BLOCK_NAME  "; fi
                         fi
                     fi
                 # NON-SUDO mode
@@ -643,7 +653,7 @@ stage_4() {
                     if [ $flag_dryrun != 1 ]; then
                         pumount -D "$BLOCK_PATH" || check_rotational "$BLOCK_NAME" && \
                         [ $flag_ignore_rotational -eq 0 ] && \
-                        txt_rotationalerror="$txt_rotationalerror$BLOCK_NAME  "
+                        if ! echo "$txt_rotationalerror" | grep "$BLOCK_NAME"; then txt_rotationalerror="$txt_rotationalerror$BLOCK_NAME  "; fi
                     fi
                 fi
             fi
